@@ -1,7 +1,6 @@
-#' @title Visualization of a correlalogram (or correlation matrix)
+#' @title Visualization of a correlation matrix
 #' @name ggcorrmat
-#' @aliases ggcorrmat
-#' @author Indrajeet Patil
+#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #' @return Correlation matrix plot or correlation coefficient matrix or matrix
 #'   of *p*-values.
 #'
@@ -84,8 +83,6 @@
 #'   `insig = "pch"`). Defaults are `pch.col = "#F0E442"` and `pch.cex = 10`.
 #' @param tl.cex,tl.col,tl.srt The size, the color, and the string rotation of
 #'   text label (variable names, i.e.).
-#' @param messages Decides whether messages references, notes, and warnings are
-#'   to be displayed (Default: `TRUE`).
 #' @inheritParams theme_ggstatsplot
 #' @inheritParams paletteer::paletteer_d
 #' @inheritParams ggscatterstats
@@ -103,6 +100,7 @@
 #' @importFrom crayon green blue yellow red
 #' @importFrom WRS2 pball
 #' @importFrom psych corr.p corr.test
+#' @importFrom pairwiseComparisons p_adjust_text
 #'
 #' @seealso \code{\link{grouped_ggcorrmat}} \code{\link{ggscatterstats}}
 #'   \code{\link{grouped_ggscatterstats}}
@@ -249,11 +247,11 @@ ggcorrmat <- function(data,
   output <- return %||% output
 
   # if any of the abbreviations have been entered, change them
-  if (corr.method == "p") {
+  if (corr.method %in% c("pearson", "p", "parametric")) {
     corr.method <- "pearson"
-  } else if (corr.method == "np") {
+  } else if (corr.method %in% c("np", "nonparametric", "non-parametric")) {
     corr.method <- "spearman"
-  } else if (corr.method == "r") {
+  } else if (corr.method %in% c("r")) {
     corr.method <- "robust"
   }
 
@@ -425,12 +423,10 @@ ggcorrmat <- function(data,
       # if `caption` is not specified, use the generic version only if
       # `caption.default` is `TRUE`
       if (is.null(caption) && pch == 4 && isTRUE(caption.default)) {
-
         # p value adjustment method description
         p.adjust.method.text <-
-          paste(
-            "Adjustment (p-value): ",
-            p.adjust.method.description(p.adjust.method = p.adjust.method),
+          paste("Adjustment (p-value): ",
+            pairwiseComparisons::p_adjust_text(p.adjust.method),
             sep = ""
           )
 
@@ -466,9 +462,7 @@ ggcorrmat <- function(data,
         )
 
       # adding ggstatsplot theme for correlation matrix
-      if (isTRUE(ggstatsplot.layer)) {
-        plot <- plot + theme_corrmat()
-      }
+      if (isTRUE(ggstatsplot.layer)) plot <- plot + theme_corrmat()
     }
   }
 
