@@ -2,14 +2,19 @@
 #' @name ggpiestats
 #' @description Pie charts for categorical data with statistical details
 #'   included in the plot as a subtitle.
-#' @author Indrajeet Patil
+#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
+#' @param x,main The variable to use as the **rows** in the contingency table.
+#' @param y,condition The variable to use as the **columns** in the contingency
+#'   table. Default is `NULL`. If `NULL`, one-sample proportion test (a goodness
+#'   of fit test) will be run for the `x` variable. Otherwise an appropriate
+#'   association test will be run.
 #' @param factor.levels A character vector with labels for factor levels of
 #'   `main` variable.
 #' @param title The text for the plot title.
 #' @param caption The text for the plot caption.
 #' @param sample.size.label Logical that decides whether sample size information
-#'   should be displayed for each level of the grouping variable `condition`
+#'   should be displayed for each level of the grouping variable `y`
 #'   (Default: `TRUE`).
 #' @param palette If a character string (e.g., `"Set1"`), will use that named
 #'   palette. If a number, will index into the list of palettes of appropriate
@@ -29,11 +34,10 @@
 #' @param label.fill.alpha Numeric that specifies fill color transparency or
 #'   `"alpha"` for slice/bar labels (Default: `1` range `0` to `1`).
 #' @param bf.message Logical that decides whether to display a caption with
-#'   results from bayes factor test in favor of the null hypothesis (default:
+#'   results from Bayes Factor test in favor of the null hypothesis (default:
 #'   `FALSE`).
-#' @inheritParams bf_contingency_tab
-#' @inheritParams subtitle_contingency_tab
-#' @inheritParams subtitle_onesample_proptest
+#' @inheritParams statsExpressions::bf_contingency_tab
+#' @inheritParams statsExpressions::expr_contingency_tab
 #' @inheritParams paletteer::scale_fill_paletteer_d
 #' @inheritParams theme_ggstatsplot
 #' @inheritParams gghistostats
@@ -68,38 +72,39 @@
 #'   `?rcompanion::cramerVFit`.
 #'
 #' @examples
-#'
+#' \donttest{
 #' # for reproducibility
 #' set.seed(123)
 #'
-#' # simple function call with the defaults (without condition)
+#' # one sample goodness of fit proportion test
 #' ggstatsplot::ggpiestats(
 #'   data = ggplot2::msleep,
-#'   main = vore,
+#'   x = vore,
 #'   perc.k = 1,
 #'   bf.message = FALSE,
 #'   k = 3
 #' )
 #'
-#' # simple function call with the defaults (with condition)
+#' # association test (or contingency table analysis)
 #' ggstatsplot::ggpiestats(
-#'   data = datasets::mtcars,
-#'   main = vs,
-#'   condition = cyl,
+#'   data = mtcars,
+#'   x = vs,
+#'   y = cyl,
 #'   bf.message = TRUE,
 #'   nboot = 10,
 #'   factor.levels = c("0 = V-shaped", "1 = straight"),
 #'   legend.title = "Engine"
 #' )
 #'
-#' # simple function call with the defaults (without condition; with count data)
+#' # using `counts` argument
 #' library(jmv, warn.conflicts = FALSE)
 #'
 #' ggstatsplot::ggpiestats(
 #'   data = as.data.frame(HairEyeColor),
-#'   main = Eye,
+#'   x = Eye,
 #'   counts = Freq
 #' )
+#' }
 #' @export
 
 # defining the function
@@ -143,42 +148,45 @@ ggpiestats <- function(data,
                        direction = 1,
                        ggplot.component = NULL,
                        return = "plot",
-                       messages = TRUE) {
+                       messages = TRUE,
+                       x = NULL,
+                       y = NULL) {
+
+  # ensure the variables work quoted or unquoted
+  main <- rlang::ensym(main)
+  condition <- if (!rlang::quo_is_null(rlang::enquo(condition))) rlang::ensym(condition)
+  x <- if (!rlang::quo_is_null(rlang::enquo(x))) rlang::ensym(x)
+  y <- if (!rlang::quo_is_null(rlang::enquo(y))) rlang::ensym(y)
+  x <- x %||% main
+  y <- y %||% condition
+  counts <- if (!rlang::quo_is_null(rlang::enquo(counts))) rlang::ensym(counts)
 
   # ================= extracting column names as labels  =====================
 
-  # saving the column label for the 'main' variables
-  if (is.null(legend.title)) {
-    legend.title <- rlang::as_name(rlang::ensym(main))
-  }
+  # saving the column label for the 'x' variables
+  if (rlang::is_null(legend.title)) legend.title <- rlang::as_name(x)
 
-  # if facetting variable name is not specified, use the variable name for
-  # 'condition' argument
-  if (!missing(condition) && rlang::is_null(facet.wrap.name)) {
-    facet.wrap.name <- rlang::as_name(rlang::ensym(condition))
+  # if facetting variable name is not specified, use 'y' variable name
+  if (!rlang::quo_is_null(rlang::enquo(y)) && rlang::is_null(facet.wrap.name)) {
+    facet.wrap.name <- rlang::as_name(y)
   }
 
   # =============================== dataframe ================================
 
   # creating a dataframe
   data %<>%
-    dplyr::select(
-      .data = .,
-      main = {{ main }},
-      condition = {{ condition }},
-      counts = {{ counts }}
-    ) %>%
+    dplyr::select(.data = ., {{ x }}, {{ y }}, {{ counts }}) %>%
     tidyr::drop_na(data = .) %>%
     tibble::as_tibble(x = .)
 
   # =========================== converting counts ============================
 
   # untable the dataframe based on the count for each observation
-  if ("counts" %in% names(data)) {
+  if (!rlang::quo_is_null(rlang::enquo(counts))) {
     data %<>%
       tidyr::uncount(
         data = .,
-        weights = counts,
+        weights = {{ counts }},
         .remove = TRUE,
         .id = "id"
       )
@@ -186,24 +194,22 @@ ggpiestats <- function(data,
 
   # ============================ percentage dataframe ========================
 
-  # main and condition need to be a factor for this analysis
+  # x and y need to be a factor for this analysis
   # also drop the unused levels of the factors
 
-  # main
-  data %<>%
-    dplyr::mutate(.data = ., main = droplevels(as.factor(main)))
+  # x
+  data %<>% dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }})))
 
-  # condition
-  if ("condition" %in% names(data)) {
-    data %<>%
-      dplyr::mutate(.data = ., condition = droplevels(as.factor(condition)))
+  # y
+  if (!rlang::quo_is_null(rlang::enquo(y))) {
+    data %<>% dplyr::mutate(.data = ., {{ y }} := droplevels(as.factor({{ y }})))
   }
 
-  # convert the data into percentages; group by conditional variable if needed
+  # convert the data into percentages; group by yal variable if needed
   # dataframe with summary labels
   df <-
     cat_label_df(
-      data = cat_counter(data, main, condition),
+      data = cat_counter(data = data, x = {{ x }}, y = {{ y }}),
       label.col.name = "slice.label",
       label.content = slice.label,
       label.separator = label.separator,
@@ -213,16 +219,22 @@ ggpiestats <- function(data,
   # ============ preparing label dataframe and other annotations  =============
 
   # dataframe containing all details needed for sample size and prop test
-  if ("condition" %in% names(data)) {
-    df_labels <- df_facet_label(data = data, x = main, y = condition)
+  if (!rlang::quo_is_null(rlang::enquo(y))) {
+    df_labels <-
+      df_facet_label(
+        data = data,
+        x = {{ x }},
+        y = {{ y }},
+        k = k
+      )
   }
 
   # reorder the category factor levels to order the legend
-  df$main <- factor(x = df$main, levels = unique(df$main))
+  df %<>% dplyr::mutate(.data = ., {{ x }} := factor({{ x }}, unique({{ x }})))
 
-  # getting labels for all levels of the 'main' variable factor
+  # getting labels for all levels of the 'x' variable factor
   if (is.null(factor.levels)) {
-    legend.labels <- as.character(df$main)
+    legend.labels <- as.character(df %>% dplyr::pull({{ x }}))
   } else {
     legend.labels <- factor.levels
   }
@@ -241,23 +253,20 @@ ggpiestats <- function(data,
   palette_message(
     package = package,
     palette = palette,
-    min_length = length(unique(levels(data$main)))[[1]]
+    min_length = nlevels(data %>% dplyr::pull({{ x }}))[[1]]
   )
 
   # creating the basic plot
-  p <- ggplot2::ggplot(
-    data = df,
-    mapping = ggplot2::aes(x = "", y = counts)
-  ) +
+  p <- ggplot2::ggplot(data = df, mapping = ggplot2::aes(x = "", y = counts)) +
     ggplot2::geom_col(
       position = "fill",
       color = "black",
       width = 1,
-      ggplot2::aes(fill = factor(get("main"))),
+      ggplot2::aes(fill = {{ x }}),
       na.rm = TRUE
     ) +
     ggplot2::geom_label(
-      ggplot2::aes(label = slice.label, group = factor(get("main"))),
+      ggplot2::aes(label = slice.label, group = {{ x }}),
       position = ggplot2::position_fill(vjust = 0.5),
       color = "black",
       size = label.text.size,
@@ -268,17 +277,16 @@ ggpiestats <- function(data,
     )
 
   # if facet_wrap is *not* happening
-  if (missing(condition)) {
-    p <- p +
-      ggplot2::coord_polar(theta = "y")
+  if (rlang::quo_is_null(rlang::enquo(y))) {
+    p <- p + ggplot2::coord_polar(theta = "y")
   } else {
     # if facet_wrap *is* happening
     p <- p +
       ggplot2::facet_wrap(
-        facets = ~condition,
+        facets = dplyr::vars({{ y }}),
         labeller = ggplot2::labeller(
-          condition = label_facet(
-            original_var = df$condition,
+          y = label_facet(
+            original_var = df %>% dplyr::pull({{ y }}),
             custom_name = facet.wrap.name
           )
         )
@@ -299,87 +307,77 @@ ggpiestats <- function(data,
     theme_pie(
       ggtheme = ggtheme,
       ggstatsplot.layer = ggstatsplot.layer
-    ) +
-    # remove black diagonal line from legend
-    ggplot2::guides(
-      fill = ggplot2::guide_legend(override.aes = list(color = NA))
-    )
+    ) + # remove black diagonal line from legend
+    ggplot2::guides(fill = ggplot2::guide_legend(override.aes = list(color = NA)))
 
   # ========================= statistical analysis ==========================
 
   # if subtitle with results is to be displayed
   if (isTRUE(results.subtitle)) {
     subtitle <-
-      subtitle_contingency_tab(
-        data = data,
-        main = main,
-        condition = condition,
-        ratio = ratio,
-        nboot = nboot,
-        paired = paired,
-        stat.title = stat.title,
-        legend.title = legend.title,
-        conf.level = conf.level,
-        conf.type = "norm",
-        bias.correct = bias.correct,
-        simulate.p.value = simulate.p.value,
-        B = B,
-        k = k,
-        messages = messages
+      tryCatch(
+        expr = statsExpressions::expr_contingency_tab(
+          data = data,
+          x = {{ x }},
+          y = {{ y }},
+          ratio = ratio,
+          nboot = nboot,
+          paired = paired,
+          stat.title = stat.title,
+          legend.title = legend.title,
+          conf.level = conf.level,
+          conf.type = "norm",
+          bias.correct = bias.correct,
+          simulate.p.value = simulate.p.value,
+          B = B,
+          k = k,
+          messages = messages
+        ),
+        error = function(e) NULL
       )
 
     # preparing Bayes Factor caption
     if (isTRUE(bf.message) && !is.null(subtitle)) {
-      caption <- bf_contingency_tab(
-        data = data,
-        main = main,
-        condition = condition,
-        sampling.plan = sampling.plan,
-        fixed.margin = fixed.margin,
-        prior.concentration = prior.concentration,
-        caption = caption,
-        output = "caption",
-        k = k
-      )
+      caption <-
+        bf_contingency_tab(
+          data = data,
+          x = {{ x }},
+          y = {{ y }},
+          sampling.plan = sampling.plan,
+          fixed.margin = fixed.margin,
+          prior.concentration = prior.concentration,
+          caption = caption,
+          output = "caption",
+          k = k
+        )
     }
   }
 
-  # if faceting by condition is happening
-  if ("condition" %in% names(data)) {
+  # if faceting by y is happening
+  if (!rlang::quo_is_null(rlang::enquo(y))) {
 
     # ================ sample size and proportion test labels =================
 
     # adding significance labels to pie charts for grouped proportion tests
     if (isTRUE(facet.proptest)) {
-
       # display grouped proportion test results
-      if (isTRUE(messages)) {
-        # tell the user what these results are
-        proptest_message(
-          main = rlang::as_name(rlang::ensym(main)),
-          condition = rlang::as_name(rlang::ensym(condition))
-        )
-
-        # print the tibble and leave out unnecessary columns
-        print(df_labels)
-      }
+      if (isTRUE(messages)) print(dplyr::select(df_labels, -label))
 
       # adding labels
-      p <-
-        p +
+      p <- p +
         ggplot2::geom_text(
           data = df_labels,
-          mapping = ggplot2::aes(label = significance, x = 1.65, y = 0.5),
+          mapping = ggplot2::aes(label = label, x = 1.65, y = 0.5),
           position = ggplot2::position_fill(vjust = 1),
-          size = 5,
-          na.rm = TRUE
+          size = 2.8,
+          na.rm = TRUE,
+          parse = TRUE
         )
     }
 
     # adding sample size info
     if (isTRUE(sample.size.label)) {
-      p <-
-        p +
+      p <- p +
         ggplot2::geom_text(
           data = df_labels,
           mapping = ggplot2::aes(label = N, x = 1.65, y = 1),
@@ -393,8 +391,7 @@ ggpiestats <- function(data,
   # =========================== putting all together ========================
 
   # preparing the plot
-  p <-
-    p +
+  p <- p +
     ggplot2::labs(
       x = NULL,
       y = NULL,
