@@ -1,16 +1,10 @@
-#' @title Scatterplot with marginal distributions
+#' @title Scatterplot with marginal distributions and statistical results
 #' @name ggscatterstats
 #' @author Indrajeet Patil, Chuck Powell
 #' @description Scatterplots from `ggplot2` combined with marginal
 #'   histograms/boxplots/density plots with statistical details added as a
 #'   subtitle.
 #'
-#' @param x The column in `data` containing the explanatory variable to be
-#'   plotted on the x axis. Can be entered either as
-#'   a character string (e.g., `"x"`) or as a bare expression (e.g, `x`).
-#' @param y The column in `data` containing the response (outcome) variable to
-#'   be plotted on the y axis. Can be entered either as
-#'   a character string (e.g., `"y"`) or as a bare expression (e.g, `y`).
 #' @param label.var Variable to use for points labels. Can be entered either as
 #'   a character string (e.g., `"var1"`) or as a bare expression (e.g, `var1`).
 #' @param label.expression An expression evaluating to a logical vector that
@@ -45,7 +39,7 @@
 #' @param point.width.jitter,point.height.jitter Degree of jitter in `x` and `y`
 #'   direction, respectively. Defaults to `0` (0%) of the resolution of the
 #'   data.
-#' @inheritParams subtitle_ggscatterstats
+#' @inheritParams statsExpressions::expr_corr_test
 #' @inheritParams ggplot2::geom_smooth
 #' @inheritParams theme_ggstatsplot
 #' @inheritParams paletteer::paletteer_d
@@ -57,9 +51,10 @@
 #' @importFrom dplyr mutate mutate_at mutate_if
 #' @importFrom rlang !! enquo quo_name parse_expr ensym as_name enexpr
 #' @importFrom ggExtra ggMarginal
-#' @importFrom stats cor.test na.omit
+#' @importFrom stats cor.test
 #' @importFrom ggrepel geom_label_repel
 #' @importFrom tibble as_tibble
+#' @importFrom statsExpressions expr_corr_test bf_corr_test
 #'
 #' @seealso \code{\link{grouped_ggscatterstats}}, \code{\link{ggcorrmat}},
 #' \code{\link{grouped_ggcorrmat}}
@@ -68,16 +63,10 @@
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggscatterstats.html}
 #'
 #' @note
-#' \itemize{
-#' \item `marginal.type = "densigram"` will work only with the development
-#'   version of `ggExtra` that you can download from `GitHub`:
-#'   `remotes::install_github("daattali/ggExtra")`.
-#'
-#' \item The plot uses `ggrepel::geom_label_repel` to attempt to keep labels
+#' The plot uses `ggrepel::geom_label_repel` to attempt to keep labels
 #' from over-lapping to the largest degree possible.  As a consequence plot
 #' times will slow down massively (and the plot file will grow in size) if you
 #' have a lot of labels that overlap.
-#' }
 #'
 #' @examples
 #'
@@ -156,22 +145,23 @@ ggscatterstats <- function(data,
 
   #---------------------- variable names --------------------------------
 
-  # if `xlab` is not provided, use the variable `x` name
-  if (is.null(xlab)) {
-    xlab <- rlang::as_name(rlang::ensym(x))
-  }
+  # ensure the arguments work quoted or unquoted
+  x <- rlang::ensym(x)
+  y <- rlang::ensym(y)
+  label.var <- if (!rlang::quo_is_null(rlang::enquo(label.var))) rlang::ensym(label.var)
 
-  # if `ylab` is not provided, use the variable `y` name
-  if (is.null(ylab)) {
-    ylab <- rlang::as_name(rlang::ensym(y))
-  }
+  # if `xlab` and `ylab` is not provided, use the variable `x` and `y` name
+  if (is.null(xlab)) xlab <- rlang::as_name(x)
+  if (is.null(ylab)) ylab <- rlang::as_name(y)
+
+  #----------------------- linear model check ----------------------------
 
-  # check the formula and the method
   # subtitle statistics is valid only for linear models, so turn off the
   # analysis if the model is not linear
   # `method` argument can be a string (`"gam"`) or function (`MASS::rlm`)
   method_ch <- paste(deparse(method), collapse = "")
 
+  # check the formula and the method
   if (as.character(deparse(formula)) != "y ~ x" ||
     if (class(method) == "function") {
       method_ch != paste(deparse(lm), collapse = "")
@@ -190,79 +180,73 @@ ggscatterstats <- function(data,
     ))
   }
 
-  #----------------------- dataframe --------------------------------------
+  #----------------------- dataframe ---------------------------------------
 
   # preparing the dataframe
-  data %<>% {
-    dplyr::full_join(
-      # bizarre names like "x...internal" and "y...internal" are used to protect
-      # against the possibility that user has already used "x" and "y"
-      x = dplyr::select(.data = ., x...internal = {{ x }}, y...internal = {{ y }}) %>%
-        tibble::rowid_to_column(., var = "rowid"),
-      # dataframe where x and y retain their original names
-      y = tibble::rowid_to_column(., var = "rowid"),
-      by = "rowid"
-    ) %>%
-      dplyr::select(.data = ., -rowid) %>% # remove NAs only from x & y columns
-      dplyr::filter(.data = ., !is.na(x...internal), !is.na(y...internal)) %>%
-      tibble::as_tibble(x = .)
-  }
+  data %<>%
+    dplyr::filter(.data = ., !is.na({{ x }}), !is.na({{ y }})) %>%
+    tibble::as_tibble(.)
 
   #---------------------------- user expression -------------------------
 
-  # create a list of function call to check for label.expression
-  param_list <- as.list(match.call())
-
   # check labeling variable has been entered
-  if ("label.var" %in% names(param_list)) {
+  if (!rlang::quo_is_null(rlang::enquo(label.var))) {
     point.labelling <- TRUE
+
+    # is expression provided?
+    if (!rlang::quo_is_null(rlang::enquo(label.expression))) {
+      expression.present <- TRUE
+    } else {
+      expression.present <- FALSE
+    }
+
+    # creating a new dataframe for showing labels
+    if (isTRUE(expression.present)) {
+      if (!rlang::quo_is_null(rlang::enquo(label.expression))) {
+        label.expression <- rlang::enexpr(label.expression)
+      }
+
+      # testing for whether we received bare or quoted
+      if (typeof(label.expression) == "language") {
+        # unquoted case
+        label_data <- dplyr::filter(.data = data, !!label.expression)
+      } else {
+        # quoted case
+        label_data <- dplyr::filter(.data = data, !!rlang::parse_expr(label.expression))
+      }
+    } else {
+      label_data <- data
+    }
   } else {
     point.labelling <- FALSE
   }
 
-  # creating a new dataframe for showing labels
-  label_expr_enxpr <- rlang::enexpr(label.expression)
-  label_data <-
-    data %>% {
-      if ("label.expression" %in% names(param_list)) {
-        # testing for whether we received bare or quoted
-        if (typeof(label_expr_enxpr) == "language") {
-          # unquoted case
-          dplyr::filter(.data = ., !!label_expr_enxpr)
-        } else {
-          # quoted case
-          dplyr::filter(.data = ., !!rlang::parse_expr(label_expr_enxpr))
-        }
-      } else {
-        (.)
-      }
-    }
-
   #----------------------- creating results subtitle ------------------------
 
   # adding a subtitle with statistical results
   if (isTRUE(results.subtitle)) {
-    subtitle <- subtitle_ggscatterstats(
-      data = data,
-      x = x...internal,
-      y = y...internal,
-      nboot = nboot,
-      beta = beta,
-      type = type,
-      conf.level = conf.level,
-      conf.type = "norm",
-      k = k,
-      stat.title = stat.title,
-      messages = messages
-    )
+    subtitle <-
+      statsExpressions::expr_corr_test(
+        data = data,
+        x = {{ x }},
+        y = {{ y }},
+        nboot = nboot,
+        beta = beta,
+        type = type,
+        conf.level = conf.level,
+        conf.type = "norm",
+        k = k,
+        stat.title = stat.title,
+        messages = messages
+      )
 
     # preparing the BF message for null hypothesis support
     if (isTRUE(bf.message)) {
       bf.caption.text <-
-        bf_corr_test(
+        statsExpressions::bf_corr_test(
           data = data,
-          x = x...internal,
-          y = y...internal,
+          x = {{ x }},
+          y = {{ y }},
           bf.prior = bf.prior,
           caption = caption,
           output = "caption",
@@ -277,7 +261,9 @@ ggscatterstats <- function(data,
   }
 
   #--------------------------------- basic plot ---------------------------
-  pos <- position_jitter(
+
+  # creating jittered positions
+  pos <- ggplot2::position_jitter(
     width = point.width.jitter,
     height = point.height.jitter,
     seed = 123
@@ -285,13 +271,14 @@ ggscatterstats <- function(data,
 
   # if user has not specified colors, then use a color palette
   if (is.null(xfill) || is.null(yfill)) {
-    colors <- paletteer::paletteer_d(
-      package = !!package,
-      palette = !!palette,
-      n = 2,
-      direction = direction,
-      type = "discrete"
-    )
+    colors <-
+      paletteer::paletteer_d(
+        package = !!package,
+        palette = !!palette,
+        n = 2,
+        direction = direction,
+        type = "discrete"
+      )
 
     # assigning selected colors
     xfill <- colors[1]
@@ -300,13 +287,7 @@ ggscatterstats <- function(data,
 
   # preparing the scatterplot
   plot <-
-    ggplot2::ggplot(
-      data = data,
-      mapping = ggplot2::aes(
-        x = x...internal,
-        y = y...internal
-      )
-    ) +
+    ggplot2::ggplot(data = data, mapping = ggplot2::aes(x = {{ x }}, y = {{ y }})) +
     ggplot2::geom_point(
       color = point.color,
       size = point.size,
@@ -340,10 +321,10 @@ ggscatterstats <- function(data,
   #----------------------- adding centrality parameters --------------------
 
   # computing summary statistics needed for displaying labels
-  x_mean <- mean(x = data$x...internal, na.rm = TRUE)
-  x_median <- median(x = data$x...internal, na.rm = TRUE)
-  y_mean <- mean(x = data$y...internal, na.rm = TRUE)
-  y_median <- median(x = data$y...internal, na.rm = TRUE)
+  x_mean <- mean(x = data %>% dplyr::pull({{ x }}), na.rm = TRUE)
+  x_median <- median(x = data %>% dplyr::pull({{ x }}), na.rm = TRUE)
+  y_mean <- mean(x = data %>% dplyr::pull({{ y }}), na.rm = TRUE)
+  y_median <- median(x = data %>% dplyr::pull({{ y }}), na.rm = TRUE)
   x_label_pos <- median(
     x = ggplot2::layer_scales(plot)$x$range$range,
     na.rm = TRUE
@@ -375,8 +356,7 @@ ggscatterstats <- function(data,
     }
 
     # adding lines
-    plot <-
-      plot +
+    plot <- plot +
       # vertical line
       ggplot2::geom_vline(
         xintercept = x.intercept,
@@ -426,29 +406,23 @@ ggscatterstats <- function(data,
   if (isTRUE(axes.range.restrict)) {
     plot <- plot +
       ggplot2::coord_cartesian(xlim = c(
-        min(data$x...internal, na.rm = TRUE),
-        max(data$x...internal, na.rm = TRUE)
+        min(data %>% dplyr::pull({{ x }}), na.rm = TRUE),
+        max(data %>% dplyr::pull({{ x }}), na.rm = TRUE)
       )) +
       ggplot2::coord_cartesian(ylim = c(
-        min(data$y...internal, na.rm = TRUE),
-        max(data$y...internal, na.rm = TRUE)
+        min(data %>% dplyr::pull({{ y }}), na.rm = TRUE),
+        max(data %>% dplyr::pull({{ y }}), na.rm = TRUE)
       ))
   }
 
   #-------------------- adding point labels --------------------------------
 
+  # using geom_repel_label
   if (isTRUE(point.labelling)) {
-    #   If we were passed a bare variable convert to char string for ggrepel
-    if (typeof(param_list$label.var) == "symbol") {
-      label.var <- deparse(substitute(label.var)) # unquoted case
-    }
-
-    # using geom_repel_label
-    plot <-
-      plot +
+    plot <- plot +
       ggrepel::geom_label_repel(
         data = label_data,
-        mapping = ggplot2::aes_string(label = label.var),
+        mapping = ggplot2::aes(label = {{ label.var }}),
         fontface = "bold",
         color = "black",
         max.iter = 3e2,
@@ -472,25 +446,24 @@ ggscatterstats <- function(data,
   # creating the `ggMarginal` plot of a given `marginal.type`
   if (isTRUE(marginal)) {
     # adding marginals to plot
-    plot <-
-      ggExtra::ggMarginal(
-        p = plot,
-        type = marginal.type,
-        margins = margins,
-        size = marginal.size,
-        xparams = list(
-          fill = xfill,
-          alpha = xalpha,
-          size = xsize,
-          col = "black"
-        ),
-        yparams = list(
-          fill = yfill,
-          alpha = yalpha,
-          size = ysize,
-          col = "black"
-        )
+    plot <- ggExtra::ggMarginal(
+      p = plot,
+      type = marginal.type,
+      margins = margins,
+      size = marginal.size,
+      xparams = list(
+        fill = xfill,
+        alpha = xalpha,
+        size = xsize,
+        col = "black"
+      ),
+      yparams = list(
+        fill = yfill,
+        alpha = yalpha,
+        size = ysize,
+        col = "black"
       )
+    )
   }
 
   #------------------------- messages  ------------------------------------
