@@ -1,10 +1,10 @@
 #' @title Box/Violin plots for group or condition comparisons in
-#'   **within**-subjects (or repeated measures) designs.
+#'   within-subjects (or repeated measures) designs.
 #' @name ggwithinstats
 #' @description A combination of box and violin plots along with raw
 #'   (unjittered) data points for within-subjects designs with statistical
 #'   details included in the plot as a subtitle.
-#' @author Indrajeet Patil
+#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
 #' @inheritParams ggbetweenstats
 #' @param path.point,path.mean Logical that decides whether individual data
@@ -13,13 +13,14 @@
 #'   there are two groups (i.e., in case of a *t*-test). In case of large number
 #'   of data points, it is advisable to set `path.point = FALSE` as these lines
 #'   can overwhelm the plot.
-#' @inheritParams subtitle_anova_parametric
+#' @inheritParams statsExpressions::expr_anova_parametric
 #'
 #' @seealso \code{\link{grouped_ggbetweenstats}}, \code{\link{ggbetweenstats}},
-#'  \code{\link{grouped_ggwithinstats}}, \code{\link{pairwise_p}}
+#'  \code{\link{grouped_ggwithinstats}}
 #'
-#' @importFrom forcats fct_reorder
-#' @importFrom rlang exec
+#' @importFrom rlang exec !! enquo :=
+#' @importFrom statsExpressions bf_ttest bf_oneway_anova
+#' @importFrom pairwiseComparisons pairwise_comparisons pairwise_comparisons_caption
 #'
 #' @details
 #'
@@ -29,7 +30,7 @@
 #'  For independent measures designs, use `ggbetweenstats`.
 #'
 #' @examples
-#'
+#' \donttest{
 #' # setup
 #' set.seed(123)
 #' library(ggstatsplot)
@@ -56,6 +57,7 @@
 #'   outlier.tagging = TRUE,
 #'   outlier.label = Taster
 #' )
+#' }
 #' @export
 
 # defining the function
@@ -64,7 +66,7 @@ ggwithinstats <- function(data,
                           y,
                           type = "parametric",
                           pairwise.comparisons = FALSE,
-                          pairwise.annotation = "asterisk",
+                          pairwise.annotation = "p.value",
                           pairwise.display = "significant",
                           p.adjust.method = "holm",
                           effsize.type = "unbiased",
@@ -122,63 +124,59 @@ ggwithinstats <- function(data,
 
   # ------------------------------ variable names ----------------------------
 
-  # if `xlab` is not provided, use the variable `x` name
-  if (is.null(xlab)) {
-    xlab <- rlang::as_name(rlang::ensym(x))
+  # ensure the variables work quoted or unquoted
+  x <- rlang::ensym(x)
+  y <- rlang::ensym(y)
+  outlier.label <- if (!rlang::quo_is_null(rlang::enquo(outlier.label))) {
+    rlang::ensym(outlier.label)
   }
 
-  # if `ylab` is not provided, use the variable `y` name
-  if (is.null(ylab)) {
-    ylab <- rlang::as_name(rlang::ensym(y))
-  }
+  # if `xlab` and `ylab` is not provided, use the variable `x` and `y` name
+  if (is.null(xlab)) xlab <- rlang::as_name(x)
+  if (is.null(ylab)) ylab <- rlang::as_name(y)
 
   # --------------------------------- data -----------------------------------
 
   # creating a dataframe
-  df <- data %>%
-    dplyr::select(
-      .data = .,
-      x = {{ x }},
-      y = {{ y }},
-      outlier.label = {{ outlier.label }}
-    ) %>%
-    dplyr::mutate(.data = ., x = droplevels(as.factor(x))) %>%
+  data %<>%
+    dplyr::select(.data = ., {{ x }}, {{ y }}, outlier.label = {{ outlier.label }}) %>%
+    dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
     tibble::as_tibble(x = .)
 
   # figuring out number of levels in the grouping factor
-  x_n_levels <- length(levels(df$x))[[1]]
+  x_n_levels <- nlevels(data %>% dplyr::pull({{ x }}))[[1]]
 
   # removing observations that don't have all repeated values
-  df %<>%
-    dplyr::filter(.data = ., !is.na(x)) %>%
-    dplyr::group_by(.data = ., x) %>%
+  data %<>%
+    dplyr::filter(.data = ., !is.na({{ x }})) %>%
+    dplyr::group_by(.data = ., {{ x }}) %>%
     dplyr::mutate(.data = ., id = dplyr::row_number()) %>%
     dplyr::ungroup(x = .) %>%
-    dplyr::filter(.data = ., !is.na(y)) %>%
+    dplyr::filter(.data = ., !is.na({{ y }})) %>%
     dplyr::group_by(.data = ., id) %>%
     dplyr::mutate(.data = ., n = dplyr::n()) %>%
     dplyr::ungroup(x = .) %>%
     dplyr::filter(.data = ., n == x_n_levels) %>%
     dplyr::select(.data = ., -n)
 
-  # if outlier.label column is not present, just use the values from `y` column
-  if (!"outlier.label" %in% names(df)) {
-    df %<>% dplyr::mutate(.data = ., outlier.label = y)
+  # if `outlier.label` column is not present, just use the values from `y` column
+  if (rlang::quo_is_null(rlang::enquo(outlier.label))) {
+    data %<>% dplyr::mutate(.data = ., outlier.label = {{ y }})
   }
 
   # add a logical column indicating whether a point is or is not an outlier
-  df %<>%
+  data %<>%
     outlier_df(
       data = .,
-      x = x,
-      y = y,
+      x = {{ x }},
+      y = {{ y }},
       outlier.coef = outlier.coef,
       outlier.label = outlier.label
     )
 
   # figure out which test to run based on the number of levels of the
   # independent variables
-  if (length(levels(as.factor(df$x))) < 3) {
+  if (nlevels(data %>% dplyr::pull({{ x }}))[[1]] < 3) {
     test <- "t-test"
   } else {
     test <- "anova"
@@ -188,11 +186,11 @@ ggwithinstats <- function(data,
 
   # if sorting is happening
   if (sort != "none") {
-    df %<>%
+    data %<>%
       sort_xy(
         data = .,
-        x = x,
-        y = y,
+        x = {{ x }},
+        y = {{ y }},
         sort = sort,
         sort.fun = sort.fun
       )
@@ -202,17 +200,17 @@ ggwithinstats <- function(data,
 
   # plot
   plot <- ggplot2::ggplot(
-    data = df,
-    mapping = ggplot2::aes(x = x, y = y, group = id)
+    data = data,
+    mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}, group = id)
   ) +
     ggplot2::geom_point(
       alpha = 0.5,
       size = 3,
       na.rm = TRUE,
-      ggplot2::aes(color = factor(x))
+      ggplot2::aes(color = {{ x }})
     ) +
     ggplot2::geom_boxplot(
-      mapping = ggplot2::aes(x = x, y = y),
+      mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}),
       inherit.aes = FALSE,
       fill = "white",
       width = 0.2,
@@ -221,7 +219,7 @@ ggwithinstats <- function(data,
       notchwidth = notchwidth
     ) +
     ggplot2::geom_violin(
-      mapping = ggplot2::aes(x = x, y = y),
+      mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}),
       inherit.aes = FALSE,
       width = 0.5,
       alpha = 0.2,
@@ -243,25 +241,22 @@ ggwithinstats <- function(data,
   # --------------------- subtitle/caption preparation ------------------------
 
   if (isTRUE(results.subtitle)) {
-    # figuring out which effect size to use
-    effsize.type <- effsize_type_switch(effsize.type)
-
     # preparing the bayes factor message
     if (type %in% c("parametric", "p") && isTRUE(bf.message)) {
       # choosing the appropriate test
       if (test == "t-test") {
-        .f <- bf_ttest
+        .f <- statsExpressions::bf_ttest
       } else {
-        .f <- bf_oneway_anova
+        .f <- statsExpressions::bf_oneway_anova
       }
 
       # preparing the BF message for null
       caption <-
         rlang::exec(
           .fn = .f,
-          data = df,
-          x = "x",
-          y = "y",
+          data = data,
+          x = rlang::as_string(x),
+          y = rlang::as_string(y),
           bf.prior = bf.prior,
           caption = caption,
           paired = TRUE,
@@ -277,9 +272,9 @@ ggwithinstats <- function(data,
         type = type,
         test = test,
         # arguments relevant for subtitle helper functions
-        data = df,
-        x = x,
-        y = y,
+        data = data,
+        x = {{ x }},
+        y = {{ y }},
         paired = TRUE,
         effsize.type = effsize.type,
         partial = partial,
@@ -304,17 +299,13 @@ ggwithinstats <- function(data,
   # already created.
 
   if (isTRUE(outlier.tagging)) {
-    # finding and tagging the outliers
-    data_outlier_label <- df %>%
-      dplyr::filter(.data = ., isanoutlier) %>%
-      dplyr::select(.data = ., -outlier)
-
     # applying the labels to tagged outliers with ggrepel
     plot <-
       plot +
       ggrepel::geom_label_repel(
-        data = data_outlier_label,
-        mapping = ggplot2::aes(x = x, y = y, label = outlier.label),
+        data = dplyr::filter(.data = data, isanoutlier) %>%
+          dplyr::select(.data = ., -outlier),
+        mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}, label = outlier.label),
         fontface = "bold",
         color = outlier.label.color,
         max.iter = 3e2,
@@ -334,9 +325,9 @@ ggwithinstats <- function(data,
   # mean plus its CI
   mean_dat <-
     mean_labeller(
-      data = df,
-      x = x,
-      y = y,
+      data = data,
+      x = {{ x }},
+      y = {{ y }},
       mean.ci = mean.ci,
       k = k
     )
@@ -345,6 +336,8 @@ ggwithinstats <- function(data,
   if (isTRUE(mean.plotting)) {
     plot <- mean_ggrepel(
       plot = plot,
+      x = {{ x }},
+      y = {{ y }},
       mean.data = mean_dat,
       mean.size = mean.size,
       mean.color = mean.color,
@@ -359,7 +352,7 @@ ggwithinstats <- function(data,
       plot <- plot +
         ggplot2::geom_path(
           data = mean_dat,
-          mapping = ggplot2::aes(x = x, y = y, group = 1),
+          mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}, group = 1),
           color = "red",
           size = 2,
           alpha = 0.5,
@@ -372,8 +365,7 @@ ggwithinstats <- function(data,
 
   # adding sample size labels to the x axes
   if (isTRUE(sample.size.label)) {
-    plot <- plot +
-      ggplot2::scale_x_discrete(labels = c(unique(mean_dat$n_label)))
+    plot <- plot + ggplot2::scale_x_discrete(labels = c(unique(mean_dat$n_label)))
   }
 
   # ggsignif labels -----------------------------------------------------------
@@ -381,10 +373,10 @@ ggwithinstats <- function(data,
   if (isTRUE(pairwise.comparisons) && test == "anova") {
     # creating dataframe with pairwise comparison results
     df_pairwise <-
-      pairwise_p(
-        data = df,
-        x = x,
-        y = y,
+      pairwiseComparisons::pairwise_comparisons(
+        data = data,
+        x = {{ x }},
+        y = {{ y }},
         type = type,
         tr = tr,
         paired = TRUE,
@@ -395,22 +387,22 @@ ggwithinstats <- function(data,
       )
 
     # display the results if needed
-    if (isTRUE(messages)) {
-      print(df_pairwise)
-    }
+    if (isTRUE(messages)) print(dplyr::select(df_pairwise, -p.value.label))
 
     # adding the layer for pairwise comparisons
     plot <- ggsignif_adder(
       plot = plot,
       df_pairwise = df_pairwise,
-      data = df,
+      data = data,
+      x = {{ x }},
+      y = {{ y }},
       pairwise.annotation = pairwise.annotation,
       pairwise.display = pairwise.display
     )
 
     # preparing the caption for pairwise comparisons test
     caption <-
-      pairwise_p_caption(
+      pairwiseComparisons::pairwise_comparisons_caption(
         type = type,
         var.equal = TRUE,
         paired = TRUE,
@@ -426,7 +418,7 @@ ggwithinstats <- function(data,
     plot <-
       aesthetic_addon(
         plot = plot,
-        x = df$x,
+        x = data %>% dplyr::pull({{ x }}),
         xlab = xlab,
         ylab = ylab,
         title = title,
@@ -441,10 +433,14 @@ ggwithinstats <- function(data,
       )
 
     # don't do scale restriction in case of post hoc comparisons
-    if (isTRUE(axes.range.restrict) && !isTRUE(pairwise.comparisons)) {
+    if (isTRUE(axes.range.restrict) && isFALSE(pairwise.comparisons)) {
+      # pull out vector for y-values
+      y_vec <- data %>% dplyr::pull({{ y }})
+
+      # restricting axes
       plot <- plot +
-        ggplot2::coord_cartesian(ylim = c(min(df$y), max(df$y))) +
-        ggplot2::scale_y_continuous(limits = c(min(df$y), max(df$y)))
+        ggplot2::coord_cartesian(ylim = c(min(y_vec), max(y_vec))) +
+        ggplot2::scale_y_continuous(limits = c(min(y_vec), max(y_vec)))
     }
   }
   # --------------------- messages ------------------------------------------
@@ -452,7 +448,7 @@ ggwithinstats <- function(data,
   if (isTRUE(messages)) {
     # display normality test result as a message
     normality_message(
-      x = df$y,
+      x = data %>% dplyr::pull({{ y }}),
       lab = ylab,
       k = k,
       output = "message"
@@ -460,9 +456,9 @@ ggwithinstats <- function(data,
 
     # display homogeneity of variance test as a message
     bartlett_message(
-      data = df,
-      x = x,
-      y = y,
+      data = data,
+      x = {{ x }},
+      y = {{ y }},
       lab = xlab,
       k = k,
       output = "message"
