@@ -14,8 +14,7 @@
 #' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang !! enquo quo_name ensym
-#' @importFrom glue glue
-#' @importFrom purrr map set_names
+#' @importFrom purrr map
 #'
 #' @seealso \code{\link{ggbarstats}}, \code{\link{ggpiestats}},
 #'  \code{\link{grouped_ggpiestats}}
@@ -32,8 +31,8 @@
 #'
 #' ggstatsplot::grouped_ggbarstats(
 #'   data = as.data.frame(HairEyeColor),
-#'   main = Hair,
-#'   condition = Eye,
+#'   x = Hair,
+#'   y = Eye,
 #'   counts = Freq,
 #'   grouping.var = Sex
 #' )
@@ -51,8 +50,8 @@
 #' # plot
 #' ggstatsplot::grouped_ggbarstats(
 #'   data = diamonds_short,
-#'   main = color,
-#'   condition = clarity,
+#'   x = color,
+#'   y = clarity,
 #'   grouping.var = cut,
 #'   sampling.plan = "poisson",
 #'   title.prefix = "Quality",
@@ -111,86 +110,63 @@ grouped_ggbarstats <- function(data,
                                ggplot.component = NULL,
                                return = "plot",
                                messages = TRUE,
+                               x = NULL,
+                               y = NULL,
                                ...) {
 
   # ======================== check user input =============================
 
-  # create a list of function call to check
-  param_list <- as.list(match.call())
-
   # check that there is a grouping.var
-  if (!"grouping.var" %in% names(param_list)) {
+  if (!"grouping.var" %in% names(as.list(match.call()))) {
     stop("You must specify a grouping variable")
   }
 
-  # check that conditioning and grouping.var are different
-  if ("condition" %in% names(param_list)) {
-    if (as.character(param_list$condition) == as.character(param_list$grouping.var)) {
-      message(cat(
-        crayon::red("\nError: "),
-        crayon::blue(
-          "Identical variable (",
-          crayon::yellow(param_list$condition),
-          ") was used for both grouping and conditioning, which is not allowed.\n"
-        ),
-        sep = ""
-      ))
-      return(invisible(param_list$condition))
-    }
-  }
-
   # ensure the grouping variable works quoted or unquoted
   grouping.var <- rlang::ensym(grouping.var)
+  main <- rlang::ensym(main)
+  condition <- if (!rlang::quo_is_null(rlang::enquo(condition))) rlang::ensym(condition)
+  x <- if (!rlang::quo_is_null(rlang::enquo(x))) rlang::ensym(x)
+  y <- if (!rlang::quo_is_null(rlang::enquo(y))) rlang::ensym(y)
+  x <- x %||% main
+  y <- y %||% condition
+  counts <- if (!rlang::quo_is_null(rlang::enquo(counts))) rlang::ensym(counts)
+
+  # check that conditioning and grouping.var are different
+  if (rlang::as_name(y) == rlang::as_name(grouping.var)) {
+    message(cat(
+      crayon::red("\nError: "),
+      crayon::blue(
+        "Identical variable (",
+        crayon::yellow(rlang::as_name(y)),
+        ") was used for both grouping and conditioning, which is not allowed.\n"
+      ),
+      sep = ""
+    ))
+    return(invisible(rlang::as_name(y)))
+  }
 
   # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) {
-    title.prefix <- rlang::as_name(grouping.var)
-  }
+  if (is.null(title.prefix)) title.prefix <- rlang::as_name(grouping.var)
 
   # ======================== preparing dataframe =============================
 
   # creating a dataframe
   df <-
-    data %>%
-    dplyr::select(
-      .data = .,
-      {{ grouping.var }},
-      {{ main }},
-      {{ condition }},
-      {{ counts }}
-    ) %>%
+    dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}, {{ counts }}) %>%
     tidyr::drop_na(data = .) %>% # creating a list for grouped analysis
     grouped_list(data = ., grouping.var = {{ grouping.var }})
 
-  # ============== build pmap list based on conditions =====================
-
-  if (missing(counts)) {
-    flexiblelist <- list(
-      data = df,
-      main = rlang::quo_text(ensym(main)),
-      condition = rlang::quo_text(ensym(condition)),
-      title = glue::glue("{title.prefix}: {names(df)}")
-    )
-  }
-
-  if (!missing(counts)) {
-    flexiblelist <- list(
-      data = df,
-      main = rlang::quo_text(ensym(main)),
-      condition = rlang::quo_text(ensym(condition)),
-      counts = rlang::quo_text(ensym(counts)),
-      title = glue::glue("{title.prefix}: {names(df)}")
-    )
-  }
-
-  # ==================== creating a list of plots =======================
+  # ================ creating a list of return objects ========================
 
   # creating a list of plots using `pmap`
   plotlist_purrr <-
     purrr::pmap(
-      .l = flexiblelist,
+      .l = list(data = df, title = paste(title.prefix, ": ", names(df), sep = "")),
       .f = ggstatsplot::ggbarstats,
       # put common parameters here
+      x = {{ x }},
+      y = {{ y }},
+      counts = {{ counts }},
       ratio = ratio,
       paired = paired,
       results.subtitle = results.subtitle,
@@ -234,21 +210,11 @@ grouped_ggbarstats <- function(data,
     )
 
   # combining the list of plots into a single plot
+  # inform user this can't be modified further with ggplot commands
   if (return == "plot") {
-    combined_object <-
-      ggstatsplot::combine_plots(
-        plotlist = plotlist_purrr,
-        ...
-      )
-
-    # inform user this can't be modified further with ggplot commands
-    if (isTRUE(messages)) {
-      grouped_message()
-    }
+    if (isTRUE(messages)) grouped_message()
+    return(ggstatsplot::combine_plots(plotlist = plotlist_purrr, ...))
   } else {
-    combined_object <- plotlist_purrr
+    return(plotlist_purrr)
   }
-
-  # return the combined plot
-  return(combined_object)
 }
