@@ -12,7 +12,6 @@
 #' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang !! enquo quo_name ensym
-#' @importFrom glue glue
 #' @importFrom purrr pmap
 #' @importFrom tidyr drop_na
 #'
@@ -23,7 +22,11 @@
 #' @inherit gghistostats return details
 #'
 #' @examples
+#' \donttest{
+#' # for reproducibility
+#' set.seed(123)
 #'
+#' # plot
 #' ggstatsplot::grouped_gghistostats(
 #'   data = iris,
 #'   x = Sepal.Length,
@@ -37,6 +40,7 @@
 #'   ),
 #'   messages = FALSE
 #' )
+#' }
 #' @export
 #'
 
@@ -95,22 +99,20 @@ grouped_gghistostats <- function(data,
   grouping.var <- rlang::ensym(grouping.var)
 
   # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) {
-    title.prefix <- rlang::as_name(grouping.var)
-  }
+  if (is.null(title.prefix)) title.prefix <- rlang::as_name(grouping.var)
 
   # maximum value for x
   binmax <-
-    dplyr::select(.data = data, !!rlang::enquo(x)) %>%
+    dplyr::select(.data = data, {{ x }}) %>%
     max(x = ., na.rm = TRUE)
 
   # minimum value for x
   binmin <-
-    dplyr::select(.data = data, !!rlang::enquo(x)) %>%
+    dplyr::select(.data = data, {{ x }}) %>%
     min(x = ., na.rm = TRUE)
 
   # number of datapoints
-  bincount <- as.integer(data %>% dplyr::count(x = .))
+  bincount <- as.integer(data %>% dplyr::count(.))
 
   # adding some binwidth sanity checking
   if (is.null(binwidth)) {
@@ -122,23 +124,17 @@ grouped_gghistostats <- function(data,
   # getting the dataframe ready
   # creating a dataframe
   df <-
-    data %>%
-    dplyr::select(.data = ., {{ grouping.var }}, {{ x }}) %>%
+    dplyr::select(.data = data, {{ grouping.var }}, {{ x }}) %>%
     tidyr::drop_na(data = .) %>% # creating a list for grouped analysis
     grouped_list(data = ., grouping.var = {{ grouping.var }})
 
-  # list with basic arguments
-  flexiblelist <- list(
-    data = df,
-    x = rlang::quo_text(rlang::ensym(x)),
-    title = glue::glue("{title.prefix}: {names(df)}")
-  )
-
   # creating a list of plots
   plotlist_purrr <-
     purrr::pmap(
-      .l = flexiblelist,
+      .l = list(data = df, title = paste(title.prefix, ": ", names(df), sep = "")),
       .f = ggstatsplot::gghistostats,
+      # put common parameters here
+      x = {{ x }},
       bar.measure = bar.measure,
       xlab = xlab,
       stat.title = stat.title,
@@ -184,21 +180,11 @@ grouped_gghistostats <- function(data,
     )
 
   # combining the list of plots into a single plot
+  # inform user this can't be modified further with ggplot commands
   if (return == "plot") {
-    combined_object <-
-      ggstatsplot::combine_plots(
-        plotlist = plotlist_purrr,
-        ...
-      )
-
-    # inform user this can't be modified further with ggplot commands
-    if (isTRUE(messages)) {
-      grouped_message()
-    }
+    if (isTRUE(messages)) grouped_message()
+    return(ggstatsplot::combine_plots(plotlist = plotlist_purrr, ...))
   } else {
-    combined_object <- plotlist_purrr
+    return(plotlist_purrr)
   }
-
-  # return the combined plot
-  return(combined_object)
 }
