@@ -14,7 +14,6 @@
 #' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang !! enquo quo_name ensym !!!
-#' @importFrom glue glue
 #' @importFrom purrr pmap
 #'
 #' @seealso \code{\link{ggwithinstats}}, \code{\link{ggbetweenstats}},
@@ -24,7 +23,7 @@
 #' @inherit ggwithinstats return details
 #'
 #' @examples
-#'
+#' \donttest{
 #' # to get reproducible results from bootstrapping
 #' set.seed(123)
 #' library(ggstatsplot)
@@ -37,6 +36,7 @@
 #'   grouping.var = order,
 #'   messages = TRUE
 #' )
+#' }
 #' @export
 
 # defining the function
@@ -47,7 +47,7 @@ grouped_ggwithinstats <- function(data,
                                   title.prefix = NULL,
                                   type = "parametric",
                                   pairwise.comparisons = FALSE,
-                                  pairwise.annotation = "asterisk",
+                                  pairwise.annotation = "p.value",
                                   pairwise.display = "significant",
                                   p.adjust.method = "holm",
                                   effsize.type = "unbiased",
@@ -123,11 +123,14 @@ grouped_ggwithinstats <- function(data,
 
   # ensure the grouping variable works quoted or unquoted
   grouping.var <- rlang::ensym(grouping.var)
+  x <- rlang::ensym(x)
+  y <- rlang::ensym(y)
+  outlier.label <- if (!rlang::quo_is_null(rlang::enquo(outlier.label))) {
+    rlang::ensym(outlier.label)
+  }
 
   # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) {
-    title.prefix <- rlang::as_name(grouping.var)
-  }
+  if (is.null(title.prefix)) title.prefix <- rlang::as_name(grouping.var)
 
   # ======================== preparing dataframe ==========================
 
@@ -144,45 +147,16 @@ grouped_ggwithinstats <- function(data,
     tidyr::drop_na(data = .) %>% # creating a list for grouped analysis
     grouped_list(data = ., grouping.var = {{ grouping.var }})
 
-  # ============== build pmap list based on conditions =====================
-
-  if (!"outlier.tagging" %in% names(param_list) || isFALSE(outlier.tagging)) {
-    flexiblelist <- list(
-      data = df,
-      x = rlang::quo_text(rlang::ensym(x)),
-      y = rlang::quo_text(rlang::ensym(y)),
-      title = glue::glue("{title.prefix}: {names(df)}")
-    )
-  }
-
-  if (isTRUE(outlier.tagging) && !"outlier.label" %in% names(param_list)) {
-    flexiblelist <- list(
-      data = df,
-      x = rlang::quo_text(rlang::ensym(x)),
-      y = rlang::quo_text(rlang::ensym(y)),
-      outlier.tagging = TRUE,
-      title = glue::glue("{title.prefix}: {names(df)}")
-    )
-  }
-
-  if (isTRUE(outlier.tagging) && "outlier.label" %in% names(param_list)) {
-    flexiblelist <- list(
-      data = df,
-      x = rlang::quo_text(rlang::ensym(x)),
-      y = rlang::quo_text(rlang::ensym(y)),
-      outlier.label = rlang::quo_text(rlang::ensym(outlier.label)),
-      outlier.tagging = TRUE,
-      title = glue::glue("{title.prefix}: {names(df)}")
-    )
-  }
-
   # ============== creating a list of plots using `pmap`=======================
 
   plotlist_purrr <-
     purrr::pmap(
-      .l = flexiblelist,
+      .l = list(data = df, title = paste(title.prefix, ": ", names(df), sep = "")),
       .f = ggstatsplot::ggwithinstats,
       # put common parameters here
+      x = {{ x }},
+      y = {{ y }},
+      outlier.label = {{ outlier.label }},
       type = type,
       pairwise.comparisons = pairwise.comparisons,
       pairwise.annotation = pairwise.annotation,
@@ -215,6 +189,7 @@ grouped_ggwithinstats <- function(data,
       notch = notch,
       notchwidth = notchwidth,
       linetype = linetype,
+      outlier.tagging = outlier.tagging,
       outlier.label.color = outlier.label.color,
       outlier.color = outlier.color,
       outlier.shape = outlier.shape,
@@ -234,21 +209,11 @@ grouped_ggwithinstats <- function(data,
     )
 
   # combining the list of plots into a single plot
+  # inform user this can't be modified further with ggplot commands
   if (return == "plot") {
-    combined_object <-
-      ggstatsplot::combine_plots(
-        plotlist = plotlist_purrr,
-        ...
-      )
-
-    # inform user this can't be modified further with ggplot commands
-    if (isTRUE(messages)) {
-      grouped_message()
-    }
+    if (isTRUE(messages)) grouped_message()
+    return(ggstatsplot::combine_plots(plotlist = plotlist_purrr, ...))
   } else {
-    combined_object <- plotlist_purrr
+    return(plotlist_purrr)
   }
-
-  # return the combined plot
-  return(combined_object)
 }
