@@ -30,3 +30,19 @@ magrittr::`%<>%`
 #' @export
 #' @importFrom magrittr "%$%"
 magrittr::`%$%`
+
+#' @export
+#' @importFrom rlang "%||%"
+rlang::`%||%`
+
+#' @export
+#' @importFrom rlang "%|%"
+rlang::`%|%`
+
+#' @export
+#' @importFrom tibble tibble
+tibble::tibble
+
+#' @export
+#' @importFrom tibble as_tibble
+tibble::as_tibble
